# mc-providers

A package of search providers for mediacloud, wrapping up interfaces for different social media platform.
UNDER CONSTRUCTION- Probably won't get a huge amount of attention for a little bit, but I'm putting this up now since I've done this extraction already.


Install with pip and the install script. 

Requires environment variables set for various interfaces to work correctly.


### Build

I'm using flit as a build tool. 

Build with `flit build`

Publish to test with `flit publish --repository testpypi`
Publish to production with `flit publish`
